@@ -7,6 +7,8 @@
 #       copyright (c) 2016 - 2020 mail@xqitw.cn
 # ==================================================================
 
+import json
+
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 from django.conf import settings
@@ -101,7 +103,11 @@ class ModelStatus(models.Model):
         verbose_name=_('状态'),
         null=False,
         default=0,
-        choices=helper.get_kelove_databases_settings('STATUS_CHOICES', helper.STATUS_CHOICES)
+        choices=helper.get_kelove_databases_settings('STATUS_CHOICES', helper.STATUS_CHOICES),
+        help_text=_('状态') + json.dumps(
+            dict(helper.get_kelove_databases_settings('STATUS_CHOICES', helper.STATUS_CHOICES)),
+            ensure_ascii=False
+        )
     )
 
     class Meta:
